from setuptools import setup

setup(name='np_distributions',
      version='1.0',
      description='Gaussian and binomial distributions',
      packages=['np_distributions'],
      author= 'Nadine Puetzer',
      author_email= 'nadine.puetzer@freenet.de',
      zip_safe=False)
